Methodology — timeawarepc 2022 documentation

# Methodology

## Time-Aware PC Algorithm

TPC estimates the Causal Functional Connectivity (CFC) from time series observations. [1, 2].

## PC Algorithm

PC is an algorithm for causal inference based on Directed Probabilistic Graphical Modeling (DPGM), which is suited for static data, i.e., independent and identically distributed observations. [2, 3].

## Granger Causality

Granger causality (GC) is a statistical methodology for determining whether one time series is useful in predicting another [2, 4].

## Comparison of Methodologies

The following summary compares over multiple criteria and shows the advantages of TPC.